;; Generated package description from repology.el  -*- no-byte-compile: t -*-
(define-package "repology" "1.2.2.0.20220223.122212" "Repology API access via Elisp" '((emacs "26.1")) :commit "db7ddc5593964e9cecb162627bdd2a0f59658f3f" :url "https://elpa.gnu.org/packages/repology.html" :authors '(("Nicolas Goaziou" . "mail@nicolasgoaziou.fr")) :maintainer '("Nicolas Goaziou" . "mail@nicolasgoaziou.fr") :keywords '("web"))
